<?php
/*
Plugin Name: WP-SimpleSyntaxHighlighter
Plugin URI: http://exceptionalgeeks.com/bi-curious/
Description: This plugin simply allows you to add and manage Alex Gorbatchev's JavaScript <a href="http://alexgorbatchev.com/wiki/SyntaxHighlighter">SyntaxHighlighter</a> to your blog.
Author: Pierre LaFromboise
Version: 1.0.9302
Author URI: http://exceptionalgeeks.com/bi-curious/
License: GNU Lesser General Public License (LGPLv3)
*/
if (!class_exists("SimpleSyntaxHighlighter")) {
	class SimpleSyntaxHighlighter {
		private $adminOptionsName = "plugin_SimpleSyntaxHighlighterOptions";
		private $themeurl;
		private $brushurl;
		private $cssurl;
		private $srsurl;
		
		function SimpleSyntaxHighlighter() {
			$this->themeurl = get_bloginfo( 'wpurl' ) . '/wp-content/plugins/wp-simplesyntaxhighlighter/themes/';
			$this->brushurl = get_bloginfo( 'wpurl' ) . '/wp-content/plugins/wp-simplesyntaxhighlighter/brushes/';
			$this->cssurl = get_bloginfo( 'wpurl' ) . '/wp-content/plugins/wp-simplesyntaxhighlighter/css/';
			$this->srcurl = get_bloginfo( 'wpurl' ) . '/wp-content/plugins/wp-simplesyntaxhighlighter/src/';
		}
		
		function init() {
			$this->getAdminOptions();
		}
		
		function getAdminOptions() {
			$adminOptions = array(
				'SelectedTheme' => 'default',
				'AvailableThemes' => array(
					'default' => array(
						'desc' => 'Default',
						'file' => 'shThemeDefault.css'),
					'django' => array(
						'desc' => 'Django',
						'file' => 'shThemeDjango.css'),
					'emacs' => array(
						'desc' => 'Eclipse',
						'file'=>'shThemeEclipse.css'),
					'emacs' => array(
						'desc' => 'Emacs',
						'file'=>'shThemeEmacs.css'),
					'fade2grey' => array(
						'desc' => 'Fade to Grey',
						'file' => 'shThemeFadeToGrey.css'),
					'midnight' => array(
						'desc' => 'Midnight',
						'file' => 'shThemeMidnight.css'),
					'rdark' => array(
						'desc' => 'RDark',
						'file' => 'shThemeRDark.css')
				),
				'AvailableBrushes' => array(
					'as3' => array(
						'desc'=>'ActionScript',
						'active'=>'true',
						'file'=>'shBrushAS3.js'),
					'bash' => array(
						'desc'=>'BashShell',
						'active'=>'true',
						'file'=>'shBrushBash.js'),
					'coldfusion' => array(
						'desc'=>'ColdFusion',
						'active'=>'true',
						'file'=>'shBrushColdFusion.js'),
					'cpp' => array(
						'desc'=>'C/C++',
						'active'=>'true',
						'file'=>'shBrushCpp.js'),
					'csharp' => array(
						'desc'=>'C#',
						'active'=>'true',
						'file'=>'shBrushCSharp.js'),
					'css' => array(
						'desc'=>'CSS',
						'active'=>'true',
						'file'=>'shBrushCss.js'),
					'delphi' => array(
						'desc'=>'Delphi/Pascal',
						'active'=>'true',
						'file'=>'shBrushDelphi.js'),
					'diff' => array(
						'desc'=>'Diff',
						'active'=>'true',
						'file'=>'shBrushDiff.js'),
					'erlanf' => array(
						'desc'=>'ErLang',
						'active'=>'true',
						'file'=>'shBrushErlang.js'),
					'fsharp' =>	array(
						'desc'=>'F#',
						'active'=>'true',
						'file'=>'shBrushFSharp.js'),
					'groovy' => array(
						'desc'=>'Groovy',
						'active'=>'true',
						'file'=>'shBrushGroovy.js'),
					'java' => array(
						'desc'=>'Java',
						'active'=>'true',
						'file'=>'shBrushJava.js'),
					'javafx' => array(
						'desc'=>'JavaFX',
						'active'=>'true',
						'file'=>'shBrushJavaFX.js'),
					'javascript' => array(
						'desc'=>'JavaScript',
						'active'=>'true',
						'file'=>'shBrushJScript.js'),
					'perl' => array(
						'desc'=>'Perl',
						'active'=>'true',
						'file'=>'shBrushPerl.js'),
					'php' => array(
						'desc'=>'PHP',
						'active'=>'true',
						'file'=>'shBrushPhp.js'),
					'plain' => array(
						'desc'=>'Plain',
						'active'=>'true',
						'file'=>'shBrushPlain.js'),
					'powershell' => array(
						'desc'=>'PowerShell',
						'active'=>'true',
						'file'=>'shBrushPowerShell.js'),
					'python' => array(
						'desc'=>'Python',
						'active'=>'true',
						'file'=>'shBrushPython.js'),
					'ruby' => array(
						'desc'=>'Ruby',
						'active'=>'true',
						'file'=>'shBrushRuby.js'),
					'scala' => array(
						'desc'=>'Scala',
						'active'=>'true',
						'file'=>'shBrushScala.js'),
					'ssis' => array(
						'desc'=>'SSIS',
						'active'=>'true',
						'file'=>'shSSIS.js'),
					'sql' => array(
						'desc'=>'SQL',
						'active'=>'true',
						'file'=>'shBrushSql.js'),
					'vbnet' => array(
						'desc'=>'VB.net',
						'active'=>'true',
						'file'=>'shBrushVb.js'),
					'xhtml' => array(
						'desc'=>'XML/HTML',
						'active'=>'true',
						'file'=>'shBrushXml.js')
				)
			);
			
			$currentOptions = get_option($this->adminOptionsName);
			
			if (!empty($currentOptions)) {
				//echo '<p>getAdminOptions db: '.print_r($currentOptions).'</p>';
				$adminOptions = $this->array_merge_recursive2($adminOptions,$currentOptions);
			}
			
			//echo '<p>getAdminOptions update: '.print_r($adminOptions).'</p>';
			update_option($this->adminOptionsName, $adminOptions);
			
			return $adminOptions;
		} // end getAdminOptions
		
		function array_merge_recursive2($array1,$array2) {
			foreach($array2 as $key => $value) {
				if (is_array($value) && isset($array1[$key])) {
					//echo '<p>key='.$key.' value1='.$value.' value2='.$array1[$key].'</p>';
					$array1[$key] = $this->array_merge_recursive2($array1[$key],$value);
				}
				else {
					//echo '<p>key='.$key.' value1='.$value.' value2='.$array1[$key].'</p>';
					$array1[$key] = $value;
				}
			}
			
			return $array1;
		} // end array_merge_recursive2
		
		function writeAdminPage() {
			$adminOptions = $this->getAdminOptions();
			//echo '<p>writeAdminPage init: '.print_r($adminOptions).'</p>';
			
			/* Insert Post code */
			if (isset($_POST['update_SimpleSyntaxHighlighterSettings'])) {
				if (isset($_POST['SelectedTheme'])) {
					$adminOptions['SelectedTheme'] = $_POST['SelectedTheme'];
				}
				
				foreach ($adminOptions['AvailableBrushes'] as $key => $brush) {
					if (isset($_POST[$key])) {
						$adminOptions['AvailableBrushes'][$key]['active'] = 'true';
					}
					else {
						$adminOptions['AvailableBrushes'][$key]['active'] = 'false';
					}
				}
				//echo '<p>writeAdminPage update: '.print_r($adminOptions).'</p>';
				update_option($this->adminOptionsName, $adminOptions);
?>
<div class="updated"><p><strong><?php _e("Settings Updated.", "SimpleSyntaxHighlighter");?></strong></p></div>
<?php
			}
				
?>
<h2><?php _e('Simple SyntaxHighlighter Options','SimpleSyntaxHighlighter'); ?></h2>
<form method="post" action="<?php echo get_bloginfo('wpurl').'/wp-admin/options-general.php?page=wp-simplesyntaxhighlighter.php'; ?>" class="cmxform">
<input type="hidden" name="_wp_http_referer" value="<?php echo get_bloginfo('wpurl').'/wp-admin/options-general.php?page=wp-simplesyntaxhighlighter.php'; ?>" />
	<fieldset>
		<legend><?php _e('SyntaxHighlighter Configuration','SimpleSyntaxHighlighter'); ?></legend>
		<ol>
			<li>
				<label for="SelectedTheme"><?php _e('Theme','SimpleSyntaxHighlighter'); ?></label>
				<select id="SelectedTheme" name="SelectedTheme">
<?php
				foreach ($adminOptions['AvailableThemes'] as $key => $theme) {
?>
					<option value="<?php echo $key; ?>"<?php if ($adminOptions['SelectedTheme'] == $key) { echo ' selected="selected"'; }?>><?php _e($theme['desc'],'SimpleSyntaxHighlighter'); ?></option>
<?php					
				}
?>
				</select>
			</li>
			<li>
				<fieldset>
					<legend><?php _e('Which languages should be included?','SimpleSyntaxHighlighter'); ?></legend>
<?php
				foreach ($adminOptions['AvailableBrushes'] as $key=>$brush) {
?>
					<label for="<?php echo $key; ?>"><input id="<?php echo $key; ?>" name="<?php echo $key; ?>" value="true" type="checkbox"<?php if ($brush['active'] == 'true') { echo ' checked="checked"'; } ?> /> <?php _e($brush['desc'],'SimpleSyntaxHighlighter'); ?></label>
<?php
				}
?>
				</fieldset>
			</li>
		</ol>
	</fieldset>
	<p><input type="submit" name="update_SimpleSyntaxHighlighterSettings" value="<?php _e('Update Settings','SimpleSyntaxHighlighter'); ?>" /></p>
</form>
<?php
		} // End writeAdminPage Function
		
		function writeCSS() {
			$adminOptions = $this->getAdminOptions();
			$selectedTheme = $adminOptions['SelectedTheme'];
			
			echo '	<link type="text/css" rel="stylesheet" href="' . $this->themeurl . 'shCore.css"></link>' . "\n";
			echo '	<link type="text/css" rel="stylesheet" href="' . $this->themeurl . $adminOptions['AvailableThemes'][$selectedTheme]['file'] . '"></link>' . "\n";
		} // End writeCSS Function
		
		function writeScript() {
			$adminOptions = $this->getAdminOptions();
			
			echo '	<script type="text/javascript" src="' . $this->srcurl . 'shCore.js"></script>' . "\n";
			
			foreach ($adminOptions['AvailableBrushes'] as $brush) {
				if ($brush['active']=='true') {
					echo '	<script type="text/javascript" src="' . $this->brushurl . $brush['file'] . '"></script>' . "\n";
				}
			}
			
			echo "	<script type=\"text/javascript\">SyntaxHighlighter.config.clipboardSwf='" . $this->brushurl . "clipboard.swf';SyntaxHighlighter.all();</script>\n";
		} // End writeScript Function
		
		function writeAdminCSS() {
			echo '	<link type="text/css" rel="stylesheet" href="' . $this->cssurl . 'screen.css"></link>' . "\n";
		} // End writeCSS Function
		
		function filter_plugin_actions($links, $file) {
			static $this_plugin;
			
			if( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
			
			if( $file == $this_plugin ){
				$settings_link = '<a href="options-general.php?page=wp-simplesyntaxhighlighter.php">' . __('Settings') . '</a>';
				array_unshift( $links, $settings_link );
			}
			
			return $links;
		} // End filter_plugin_actions Function
		
	} // End SimpleSyntaxHighlighter Class
}

if (class_exists("SimpleSyntaxHighlighter")) {
	$init_ssh = new SimpleSyntaxHighlighter();
}

if (!function_exists("SimpleSyntaxHighlighter_ap")) {
	function SimpleSyntaxHighlighter_ap() {
		global $init_ssh;
		if (!isset($init_ssh)) {
			return;
		}
		if (function_exists('add_options_page')) {
			add_options_page('Simple SyntaxHighlighter Options', 'Simple SyntaxHighlighter', 8, basename(__FILE__), array(&$init_ssh,'writeAdminPage'));
		}
	}
}

if (isset($init_ssh)) {
	add_action('activate_wp-simplesyntaxhighlighter/wp-simplesyntaxhighlighter.php',  array(&$init_ssh, 'init'));
	
	add_action('admin_menu', 'SimpleSyntaxHighlighter_ap');
	
	add_action('wp_head', array(&$init_ssh, 'writeCSS'), 10);
	add_action('wp_footer', array(&$init_ssh, 'writeScript'), 10);
	
	add_action('admin_head', array(&$init_ssh, 'writeAdminCSS'), 10);
	
	add_filter( 'plugin_action_links', array(&$init_ssh, 'filter_plugin_actions'), 10, 2 );
	
	register_uninstall_hook(__FILE__,'removeOptions');
	
	function removeOptions() {
		delete_option('plugin_SimpleSyntaxHighlighterOptions');
	} // End removeOptions Function
}
?>